==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Din sajts URL', # MODIF
	'form_pet_aucune_signature' => 'Inga underskrifter motsvarar denna kod...', # MODIF
	'form_pet_confirmation' => 'Var god och bekräfta din underskrift:',
	'form_pet_deja_signe' => 'Du har redan skrivit under texten.',
	'form_pet_envoi_mail_confirmation' => 'Ett epost med en begäran om bekräftelse har precis skickats till @email@. Du bör besöka den URL som står i brevet för att bekräfta din inmatning.', # MODIF
	'form_pet_mail_confirmation' => 'Hej,

Du har begärt att skriva under namninsamlingen:
@titre@.

Du angav följande information:
    Namn: @nom_email@
    Sajt: @nom_site@ - @url_site@

VIKTIGT...
För att bekräfta din underskrift behöver du besöka
adressen nedan (annars kommer din begäran att nekas:
    @url@

Tack för ditt deltagande
',
	'form_pet_nom_site2' => 'Namn på din webbssajt', # MODIF
	'form_pet_probleme_liens' => 'Var vänlig ändra ditt meddelande, ta bort alla hyperlänkar.',
	'form_pet_probleme_technique' => 'Registrering är tillfälligtvis omöjligt på grund av ett tekniskt problem.',
	'form_pet_signature_validee' => 'Din signatur är giltig. Tack!',
	'form_pet_site_deja_enregistre' => 'Den här sajten är redan registrerad',
	'form_pet_url_invalide' => 'URL:en som du angivit är inte giltig.',
	'form_pet_votre_email' => 'Din epost-adress',
	'form_pet_votre_nom' => 'Ditt namn eller aliass', # MODIF
	'form_pet_votre_site' => 'Om du har en webbssajt, kan du ange dess adress nedan',

	// I
	'info_adresse_email' => 'EMAIL-ADRESS:',
	'info_signature_supprimee' => 'Underskriften raderades',
	'info_signature_supprimee_erreur' => 'Fel: den här raderingskoden motsvarar ingen underskrift', # MODIF
	'info_site_web' => 'WEBBSAJT:',

	// L
	'lien_reponse_article' => 'Svara på artikeln'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Aktivera namninsamlingen',
	'bouton_radio_pas_petition' => 'Inga namninsamlingar',
	'bouton_radio_petition_activee' => 'Namninsamling aktiverad',
	'bouton_radio_supprimer_petition' => 'Radera namninsamlingen',

	// F
	'form_pet_adresse_site' => 'Din sajts URL', # MODIF
	'form_pet_aucune_signature' => 'Inga underskrifter motsvarar denna kod...', # MODIF
	'form_pet_confirmation' => 'Var god och bekräfta din underskrift:',
	'form_pet_deja_signe' => 'Du har redan skrivit under texten.',
	'form_pet_envoi_mail_confirmation' => 'Ett epost med en begäran om bekräftelse har precis skickats till @email@. Du bör besöka den URL som står i brevet för att bekräfta din inmatning.', # MODIF
	'form_pet_mail_confirmation' => 'Hej,

Du har begärt att skriva under namninsamlingen:
@titre@.

Du angav följande information:
    Namn: @nom_email@
    Sajt: @nom_site@ - @url_site@

VIKTIGT...
För att bekräfta din underskrift behöver du besöka
adressen nedan (annars kommer din begäran att nekas:
    @url@

Tack för ditt deltagande
',
	'form_pet_nom_site2' => 'Namn på din webbssajt', # MODIF
	'form_pet_probleme_liens' => 'Var vänlig ändra ditt meddelande, ta bort alla hyperlänkar.',
	'form_pet_probleme_technique' => 'Registrering är tillfälligtvis omöjligt på grund av ett tekniskt problem.',
	'form_pet_signature_validee' => 'Din signatur är giltig. Tack!',
	'form_pet_site_deja_enregistre' => 'Den här sajten är redan registrerad',
	'form_pet_url_invalide' => 'URL:en som du angivit är inte giltig.',
	'form_pet_votre_email' => 'Din epost-adress',
	'form_pet_votre_nom' => 'Ditt namn eller aliass', # MODIF
	'form_pet_votre_site' => 'Om du har en webbssajt, kan du ange dess adress nedan',

	// I
	'info_adresse_email' => 'EMAIL-ADRESS:',
	'info_signature_supprimee' => 'Underskriften raderades',
	'info_signature_supprimee_erreur' => 'Fel: den här raderingskoden motsvarar ingen underskrift', # MODIF
	'info_site_web' => 'WEBBSAJT:',

	// L
	'lien_reponse_article' => 'Svara på artikeln'
);

?>
